<p align="center">
    <img src='https://raw.githubusercontent.com/revrulb/thesmo-calc-fields-object/master/logo.svg?sanitize=true'></img>
</p>

![npm](https://img.shields.io/npm/v/thesmo-calc-fields-object)
![GitHub](https://img.shields.io/github/license/revrulb/thesmo-calc-fields-object)
![GitHub last commit](https://img.shields.io/github/last-commit/revrulb/thesmo-calc-fields-object)
![npm](https://img.shields.io/npm/dm/thesmo-calc-fields-object)
![GitHub top language](https://img.shields.io/github/languages/top/revrulb/thesmo-calc-fields-object)
[![code style: prettier](https://img.shields.io/badge/code_style-prettier-ff69b4.svg?style=flat-square)](https://github.com/prettier/prettier)


# Summary

This package contains **calculating fields for object source values**.

# Functions

## **getNode**

Generates UnsafeCF for obtaining node from source object
by its' path

```typescript
type Args = {
    nodePath: string;
};

type Signature = ({ nodePath }: Args) => UnsafeCF<unknown>
```

## **getObjectGuarantor**

Generates guarantor for object unsafe calculating fields

```typescript
type Args = {
    convertArrayToArrayLikeObject?: boolean;
    convertNullToEmptyObject?: boolean;
    convertUndefinedToEmptyObject?: boolean;
};

type Signature = ({
    convertArrayToArrayLikeObject = false,
    convertNullToEmptyObject = false,
    convertUndefinedToEmptyObject = false
}: Args) => Guarantor<object>
```

## **getRequiredFieldNames**

Generates UnsafeCF for obtaining names of fields which
satisfy custom check based on their names and values

```typescript
type Args = {
    check: ({ fieldName, fieldValue }: CheckArgs) => boolean;
};

type Signature = ({ check }: Args) => UnsafeCF<string[]>
```

## **merge**

Generates UnsafeCF for objects merging

```typescript
type Args<T> = {
    partToBeMergedWith: T;
};

type Signature = <
    Source extends object,
    MergingPart extends object = Partial<Source>
>({
    partToBeMergedWith
}: Args<MergingPart>) => UnsafeCF<Source & MergingPart>
```

## **updateInClone**

Generates UnsafeCF for updating source object without
changing it (modified copy will be returned)

```typescript
type Args<Source, Result> = {
    nodePath: string;
    calcField: SafeCF<Source, Result>;
};

type Signature = <Source, Result>({
    nodePath,
    calcField
}: Args<Source, Result>): UnsafeCF<object>
```

## **updateWithPattern**

Generates UnsafeCF for updating source with given pattern
(pattern makes possible to change required source fields via
calculating fields)

```typescript
type UpdatingPattern<T extends object> = Partial<
    {
        [K in keyof T]: SafeCF<T[K]>;
    }
>;

type Args<T extends object> = {
    pattern: UpdatingPattern<T>;
};

type Signature = <T extends object>({
    pattern
}: Args<T>): UnsafeCF<T>
```