/**
 *  Generates UnsafeCF for obtaining node from source object
 *  by its' path
 */
export declare const getNode: ({ nodePath }: {
    nodePath: string;
}) => import("thesmo-calc-fields-base").UnsafeCF<unknown>;
/**
 * Generates guarantor for object unsafe calculating fields
 */
export declare const getObjectsGuarantor: ({ convertArrayToArrayLikeObject, convertNullToEmptyObject, convertUndefinedToEmptyObject }: {
    convertArrayToArrayLikeObject?: boolean | undefined;
    convertNullToEmptyObject?: boolean | undefined;
    convertUndefinedToEmptyObject?: boolean | undefined;
}) => import("thesmo-calc-fields-base").Guarantor<object>;
/**
 * Generates UnsafeCF for obtaining names of fields which
 * satisfy custom check based on their names and values
 */
export declare const getRequiredFieldNames: ({ check }: {
    check: ({ fieldName, fieldValue }: {
        fieldName: string;
        fieldValue: unknown;
    }) => boolean;
}) => import("thesmo-calc-fields-base").UnsafeCF<string[]>;
/**
 * Generates UnsafeCF for objects merging
 */
export declare const merge: <Source extends object, MergingPart extends object = Partial<Source>>({ partToBeMergedWith }: {
    partToBeMergedWith: MergingPart;
}) => import("thesmo-calc-fields-base").UnsafeCF<Source & MergingPart>;
/**
 * Generates UnsafeCF for updating source with given pattern
 * (pattern makes possible to change required source fields via
 * calculating fields)
 */
export declare const updateWithPattern: <T extends object>({ pattern }: {
    pattern: Partial<{ [K in keyof T]: import("thesmo-calc-fields-base").SafeCF<T[K], T[K]>; }>;
}) => import("thesmo-calc-fields-base").UnsafeCF<T>;
/**
 * Generates UnsafeCF for updating source object without
 * changing it (modified copy will be returned)
 */
export declare const updateInClone: <Source, Result>({ nodePath, calcField }: {
    nodePath: string;
    calcField: import("thesmo-calc-fields-base").SafeCF<Source, Result>;
}) => import("thesmo-calc-fields-base").UnsafeCF<object>;
