"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var thesmo_calc_fields_base_1 = require("thesmo-calc-fields-base");
var Constants_1 = require("./ExternalData/Constants");
var Helpers_1 = require("./ExternalData/Helpers");
var GetNode_1 = __importDefault(require("./Functions/GetNode"));
var GetObjectsGuarantor_1 = __importDefault(require("./Functions/GetObjectsGuarantor"));
var GetRequiredFieldNames_1 = __importDefault(require("./Functions/GetRequiredFieldNames"));
var Merge_1 = __importDefault(require("./Functions/Merge"));
var UpdateInClone_1 = __importDefault(require("./Functions/UpdateInClone"));
var UpdateWithPattern_1 = __importDefault(require("./Functions/UpdateWithPattern"));
var isObject = function (x) {
    return typeof x === "object" && x !== null && !Array.isArray(x);
};
/**
 *  Generates UnsafeCF for obtaining node from source object
 *  by its' path
 */
exports.getNode = GetNode_1.default({
    isObject: isObject,
    nodePathSeparator: Constants_1.nodePathSeparator,
    nodePathCheck: Helpers_1.nodePathCheck,
    invalidNodePathMessage: Constants_1.invalidNodePathMessage,
    nonExistingNodeAccessMessage: Constants_1.nonExistingNodeAccessMessage
});
/**
 * Generates guarantor for object unsafe calculating fields
 */
exports.getObjectsGuarantor = GetObjectsGuarantor_1.default({
    getGuarantor: thesmo_calc_fields_base_1.getGuarantor,
    isObject: isObject
});
/**
 * Generates UnsafeCF for obtaining names of fields which
 * satisfy custom check based on their names and values
 */
exports.getRequiredFieldNames = GetRequiredFieldNames_1.default({});
/**
 * Generates UnsafeCF for objects merging
 */
exports.merge = Merge_1.default({ isObject: isObject });
/**
 * Generates UnsafeCF for updating source with given pattern
 * (pattern makes possible to change required source fields via
 * calculating fields)
 */
exports.updateWithPattern = UpdateWithPattern_1.default({});
/**
 * Generates UnsafeCF for updating source object without
 * changing it (modified copy will be returned)
 */
exports.updateInClone = UpdateInClone_1.default({
    nodePathSeparator: Constants_1.nodePathSeparator,
    isObject: isObject,
    updateWithPattern: exports.updateWithPattern,
    nodePathCheck: Helpers_1.nodePathCheck
});
